package bioinformatica.programmazione.esami.luglio.terzaparte;

/**
 * Classe che rappresenta le coalizione che si presentano ad una elezione
 * politica. Ogni coalizione e' composta da vari partiti, puo' essere anche
 * vuota.
 * 
 * @author progBioinfo
 * 
 */
public class Coalizione {

	/**
	 * Il nome della coalizione.
	 */
	private final String nome;

	/**
	 * I partiti che fanno farte della coalizione
	 */
	private Partito[] partiti;

	/**
	 * Crea una coalizione con un nome e un gruppo di partiti dati.
	 * 
	 * @param nome
	 *            il nome della coalizione.
	 * @param partiti
	 *            il gruppo di partiti in coalizione.
	 */
	public Coalizione(String nome, Partito... partiti) {
		this.nome = nome;
		this.partiti = partiti;
	}

	/**
	 * Verifica se il partito dato compare nella coalizione.
	 * 
	 * @param partito
	 *            partito da verificare
	 * @return <code>true</code> se
	 *         <code>partito<code> e' incluso nella coalizione, <code>false</code>
	 *         altrimenti.
	 */
	public boolean include(Partito partito) {
		if (partito != null)
			for (Partito p : partiti)
				if (partito.equals(p))
					return true;
		return false;
	}

	/**
	 * Restituisce il nome della coalizione.
	 * 
	 * @return il nome della coalizione.
	 */
	public String getNome() {
		return nome;
	}

	/**
	 * Restituisce i partiti in coalizione.
	 * 
	 * @return partiti in coalizione.
	 */
	public Partito[] getPartiti() {
		return partiti;
	}

	/**
	 * Restituisce i voti totali della coalizione.
	 * 
	 * @return voti totali della coalizione.
	 */
	public int getVoti() {
		int voti = 0;
		for (Partito p : partiti)
			voti += p.getVoti();
		return voti;
	}

	@Override
	public boolean equals(Object altro) {
		return altro instanceof Coalizione
				&& ((Coalizione) altro).nome.equals(nome);
	}

}